package com.bweb.controller;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.hai.common.exception.ErrorCode;
import com.hai.common.exception.ErrorHelp;
import com.hai.common.exception.SysCode;
import com.hai.common.security.SessionObject;
import com.hai.common.security.UserCenter;
import com.hai.common.utils.ResponseMsgUtil;
import com.hai.entity.HighCouponPackage;
import com.hai.entity.HighOrderPre;
import com.hai.model.ResponseData;
import com.hai.model.UserInfoModel;
import com.hai.service.HighCouponPackageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author Sum1Dream
 * @ClassName HighCouponPackageController
 * @Description // 优惠券包接口
 * @Date 2021/11/25 4:32 下午
 **/
@Controller
@RequestMapping(value = "/highCouponPackage")
@Api(value = "优惠券包接口")
public class HighCouponPackageController {

    private static Logger log = LoggerFactory.getLogger(HighOrderPreController.class);

    @Autowired
    private UserCenter userCenter;

    @Resource
    private HighCouponPackageService highCouponPackageService;

    @RequestMapping(value = "/getCouponPackageList", method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "获取优惠券包列表")
    public ResponseData getCouponPackageList(@RequestParam(name = "usingAttribution", required = false) Integer usingAttribution,
                                             @RequestParam(name = "title", required = false) String title,
                                             @RequestParam(name = "salesType", required = false) Integer salesType,
                                             @RequestParam(name = "status", required = false) Integer status,
                                             @RequestParam(name = "pageNum", required = true) Integer pageNum,
                                             @RequestParam(name = "pageSize", required = true) Integer pageSize,
                                             HttpServletRequest request) {
        try {

            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();

            Map<String,Object> map = new HashMap<>();

            map.put("companyId", userInfoModel.getBsCompany().getId());
            map.put("usingAttribution", usingAttribution);
            map.put("title" , title);
            map.put("salesType" , salesType);
            map.put("status" , status);
            PageHelper.startPage(pageNum,pageSize);
            return ResponseMsgUtil.success(new PageInfo<>(highCouponPackageService.getCouponPackageList(map)));

        } catch (Exception e) {
            log.error("HighOrderController --> getUserOrderList() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }


    @RequestMapping(value = "/highCouponPackageInfo", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "新增优惠券包基本信息")
    public ResponseData highCouponPackageInfo(@RequestBody HighCouponPackage highCouponPackage, HttpServletRequest request) {
        try {

            //发布人员
            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();

            if (StringUtils.isBlank(highCouponPackage.getTitle())
                    || highCouponPackage.getUsingAttribution() == null
                    || highCouponPackage.getSalesType() == null
                    || highCouponPackage.getEffectiveTiem() == null
                    || highCouponPackage.getPurchaseNum() == null
                    || highCouponPackage.getPrice() == null
                    || StringUtils.isBlank(highCouponPackage.getBannerImg())
                    || StringUtils.isBlank(highCouponPackage.getListImg())
                    || StringUtils.isBlank(highCouponPackage.getDetailsImg())
            ) {
                log.error("HighAgentController -> insertAgent() error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            if (userInfoModel.getBsCompany() == null) {
                log.error("highCouponPackage -> highCouponPackageInfo() error!","该主角色没有权限");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.MENU_TREE_HAS_NOT_ERROR, "");
            }

            highCouponPackage.setCompanyId(userInfoModel.getBsCompany().getId().intValue());
            highCouponPackage.setStatus(3);
            highCouponPackage.setCreatedTime(new Date());
            highCouponPackage.setCreatedUserId(userInfoModel.getSecUser().getId().intValue());
            highCouponPackage.setUpdatedTime(new Date());
            highCouponPackage.setUpdatedUserId(userInfoModel.getSecUser().getId().intValue());

            highCouponPackageService.insertCouponPackage(highCouponPackage);

            return ResponseMsgUtil.success(highCouponPackage);

        } catch (Exception e) {
            log.error("HighAgentController --> insertAgent() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

    @RequestMapping(value = "/highCouponPackageRule", method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "新增优惠券包基本信息")
    public ResponseData highCouponPackageRule(@RequestBody HighCouponPackage highCouponPackage, HttpServletRequest request) {
        try {
            //发布人员
            SessionObject sessionObject = userCenter.getSessionObject(request);
            UserInfoModel userInfoModel = (UserInfoModel) sessionObject.getObject();


            if (StringUtils.isBlank(highCouponPackage.getTitle())
                    || highCouponPackage.getUsingAttribution() == null
                    || highCouponPackage.getSalesType() == null
                    || highCouponPackage.getEffectiveTiem() == null
                    || highCouponPackage.getPurchaseNum() == null
                    || highCouponPackage.getPrice() == null
                    || StringUtils.isBlank(highCouponPackage.getBannerImg())
                    || StringUtils.isBlank(highCouponPackage.getListImg())
                    || StringUtils.isBlank(highCouponPackage.getDetailsImg())
            ) {
                log.error("HighAgentController -> insertAgent() error!","参数错误");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }

            if (userInfoModel.getBsCompany() == null) {
                log.error("highCouponPackage -> highCouponPackageInfo() error!","该主角色没有权限");
                throw ErrorHelp.genException(SysCode.System, ErrorCode.MENU_TREE_HAS_NOT_ERROR, "");
            }

            highCouponPackage.setCompanyId(userInfoModel.getBsCompany().getId().intValue());
            highCouponPackage.setStatus(3);
            highCouponPackage.setCreatedTime(new Date());
            highCouponPackage.setCreatedUserId(userInfoModel.getSecUser().getId().intValue());
            highCouponPackage.setUpdatedTime(new Date());
            highCouponPackage.setUpdatedUserId(userInfoModel.getSecUser().getId().intValue());

            highCouponPackageService.insertCouponPackage(highCouponPackage);

            return ResponseMsgUtil.success(highCouponPackage);

        } catch (Exception e) {
            log.error("HighAgentController --> insertAgent() error!", e);
            return ResponseMsgUtil.exception(e);
        }
    }

}
