package com.hai.service.impl;

import com.hai.dao.HighCouponPackageMapper;
import com.hai.entity.HighCouponPackage;
import com.hai.entity.HighCouponPackageExample;
import com.hai.service.HighCouponPackageService;
import org.apache.commons.collections4.MapUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @serviceName HighCouponPackageServiceImpl.java
 * @author Sum1Dream
 * @version 1.0.0
 * @Description // 优惠券包 接口
 * @createTime 12:21 下午 2021/11/25
 **/
@Service("highCouponPackageService")
public class HighCouponPackageServiceImpl implements HighCouponPackageService {

    @Resource
    private HighCouponPackageMapper highCouponPackageMapper;

    @Override
    public List<HighCouponPackage> getCouponPackageList(Map<String, Object> map) {

        HighCouponPackageExample example = new HighCouponPackageExample();
        HighCouponPackageExample.Criteria criteria = example.createCriteria();

        if (MapUtils.getInteger(map, "companyId") != null) {
            criteria.andCompanyIdEqualTo(MapUtils.getInteger(map, "companyId"));
        }

        if (MapUtils.getInteger(map, "usingAttribution") != null) {
            criteria.andUsingAttributionEqualTo(MapUtils.getInteger(map, "usingAttribution"));
        }

        if (MapUtils.getString(map, "title") != null) {
            criteria.andTitleLike("%" + MapUtils.getString(map, "title") + "%");
        }

        if (MapUtils.getInteger(map, "salesType") != null) {
            criteria.andSalesTypeEqualTo(MapUtils.getInteger(map, "salesType"));
        }

        if (MapUtils.getInteger(map, "status") != null) {
            criteria.andStatusEqualTo(MapUtils.getInteger(map, "status"));
        } else {
            criteria.andStatusNotEqualTo(0);
        }

        example.setOrderByClause("created_time desc");

        return highCouponPackageMapper.selectByExample(example);
    }

    @Override
    public HighCouponPackage findCouponPackageById(Integer id) {
        return highCouponPackageMapper.selectByPrimaryKey(id);
    }

    @Override
    public void insertCouponPackage(HighCouponPackage highCouponPackage) {
        highCouponPackageMapper.insert(highCouponPackage);
    }

    @Override
    public void updateCouponPackage(HighCouponPackage highCouponPackage) {
        highCouponPackageMapper.updateByPrimaryKey(highCouponPackage);
    }
}
